@@ -32,6 +32,9 @@ transmute_nse <- function(.data, ...,  transmute_nse_env = parent.frame()) {
   # convert char vector into spliceable vector
   # from: https://github.com/tidyverse/rlang/issues/116
   transmuteTerms <- substitute(list(...))
+  if(!all(names(transmuteTerms) %in% "")) {
+    stop("seplyr::transmute_nse() unexpected names in '...', all assignments must be of the form a := b, not a = b")
+  }
   # transmuteTerms is a list of k+1 items, first is "list" the rest are captured expressions
   res <- .data
   len <- length(transmuteTerms)
