@@ -4,28 +4,27 @@
 #' transmute a data frame by the transmuteTerms.  Accepts arbitrary text as
 #' transmuteTerms to allow forms such as "Sepal.Length >= 2 * Sepal.Width".
 #'
-#' @seealso \code{\link[dplyr]{transmute}}, \code{\link[dplyr]{transmute_at}}, \code{\link[seplyr]{:=}}
+#' @seealso \code{\link[dplyr]{transmute}}, \code{\link[dplyr]{transmute_at}}, \code{\link[wrapr]{:=}}
 #'
 #' @param .data data.frame
 #' @param transmuteTerms character vector of column expressions to transmute by.
+#' @param env environment to work in.
 #' @return .data transumuted by transmuteTerms.
 #'
 #' @examples
 #'
-#' suppressPackageStartupMessages(library("dplyr"))
 #'
-#' datasets::iris %>%
-#'   transmute_se(c("Sepal_Long" := "Sepal.Length >= 2 * Sepal.Width",
-#'               "Petal_Short" := "Petal.Length <= 3.5")) %>%
-#'   summary()
+#' datasets::iris %.>%
+#'   transmute_se(., c("Sepal_Long" := "Sepal.Length >= 2 * Sepal.Width",
+#'                     "Petal_Short" := "Petal.Length <= 3.5")) %.>%
+#'   summary(.)
 #'
 #'
 #' @export
 #'
-transmute_se <- function(.data, transmuteTerms) {
+transmute_se <- function(.data, transmuteTerms,  env=parent.frame()) {
   # convert char vector into spliceable vector
   # from: https://github.com/tidyverse/rlang/issues/116
-  env <- parent.frame()
   transmuteQ <- lapply(transmuteTerms,
                        function(si) {
                          rlang::parse_quosure(si,
